@@ -1,7 +1,7 @@
 mapping = {
-    # "default": {
-    #     "core_allocation": [0, 1, 2, 3],
-    # },
+    "default": {
+        "core_allocation": [0, 1, 2, 3],
+    },
     "Conv": {
         "core_allocation": [0, 1, 2, 3],
     },
